# -*- coding: utf-8 -*-
"""
Create an identifier to print it on a plot.

Functions:
    create_id(str) -> string
"""
import time
import uuid


def create_id(id_method):
    """
    Create an Identifier (str).

    Creates an (sometimes unique) identifier based on the selected method
    if no method is selected method 1 will be the default method

    Returns
    -------
    figure_id
    """
    match id_method:
        case 'time':
            figure_id = time.time()  # UNIX Time
            figure_id = hex(int(figure_id))  # convert time to hexadecimal
            time.sleep(0.5)   # break for avoiding duplicate IDs
        case 'random':
            figure_id = str(uuid.uuid4())  # creates a random UUID
            figure_id = figure_id[0:8]            # only use first 8 numbers
        case _:
            raise ValueError(
                f'Your chosen ID method "{id_method}" is not supported.\n'
                'At the moment these methods are available:\n'
                '"time": Unix time converted to hexadecimal\n'
                '"random": Random UUID')
    return figure_id
