# -*- coding: utf-8 -*-
"""
Example workflow for integrating plotID.

With tagplot an ID can be generated an printed on the plot. To export the plot
along with the corresponding research data and the plot generating script use
the function publish.
"""

# %% Import modules
import numpy as np
# import h5py as h5
import matplotlib.pyplot as plt
from plotid.tagplot import tagplot
from plotid.publish import publish

# %% Set Project ID
PROJECT_ID = "MR04_"

# %% Choose Plot engine
PLOT_ENGINE = "matplotlib"

# %% Create sample data
x = np.linspace(0, 10, 100)
y = np.random.rand(100) + 2
y_2 = np.sin(x) + 2

# %% Create figures

# 1. figure
FIG1 = plt.figure()
plt.plot(x, y, color='black')
plt.plot(x, y_2, color='yellow')

# 2. figure
FIG2 = plt.figure()
plt.plot(x, y, color='blue')
plt.plot(x, y_2, color='red')

# %% TagPlot

# If multiple figures should be tagged, figures must be provided as list.
FIGS_AS_LIST = [FIG1, FIG2]

[TAGGED_FIGS, ID] = tagplot(FIGS_AS_LIST, PLOT_ENGINE, prefix=PROJECT_ID,
                            id_method='random', location='west')

# %% Save figure as tiff-file, but publish also exports the plot to a picture
# file in the destination folder.
for i, figure in enumerate(TAGGED_FIGS):
    NAME = "Test"+str(i)+".tiff"
    figure.savefig(NAME)

# %% Publish
# Arguments: Source directory, destination directory, figure, plot name,
# publish-mode).
publish('../../tests', '/home/chief/Dokumente/fst/plotid_python/data',
        FIG1, 'Bild', 'individual')
