#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Contains the PlotOption class."""


class PlotOptions:
    """
    Container objects which include all plot options provided by plotid.

    Methods
    -------
    __init__
    validate_input: Check if input is correct type.

    Attributes
    ----------
    figs : figure object
        Figure that will be tagged.
    prefix : str
        Prefix that is placed before the ID.
    id_method : int
        Method that decides which method is used to generate the ID.
    rotation : int
        Rotation angle for the ID.
    position : tuple
        Relative position of the ID on the plot (x,y).
    """

    def __init__(self, figs, prefix, id_method, rotation, position):

        self.figs = figs
        self.prefix = prefix
        self.id_method = id_method
        self.rotation = rotation
        self.position = position

    def validate_input(self):
        """
        Validate if input for PlotOptions is correct type.

        Raises
        ------
        TypeError
            TypeError is thrown if one of the attributes is not the correct
            type.

        Returns
        -------
        0, if all checks succeed.

        """
        # %% Validate inputs
        # Input validation for figs is done in submodules tagplot_$engine.py
        if isinstance(self.prefix, str):
            pass
        else:
            raise TypeError("Prefix is not a string.")

        if isinstance(self.id_method, str):
            pass
        else:
            raise TypeError('The chosen id_method is not a string.')

        return 0
