#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Unittests for tagplot
"""

import unittest
import matplotlib.pyplot as plt
from plotid.tagplot import tagplot

# Constants for tests
FIG1 = plt.figure()
FIG2 = plt.figure()
FIGS_AS_LIST = [FIG1, FIG2]

PROJECT_ID = "MR01"
PLOT_ENGINE = "matplotlib"
METHOD = 'time'


class TestTagplot(unittest.TestCase):
    """
    Class for all unittests of the tagplot module.
    """

    def test_prefix(self):
        """ Test if Error is raised if prefix is not a string. """
        with self.assertRaises(TypeError):
            tagplot(FIGS_AS_LIST, PLOT_ENGINE, 3, METHOD, location='southeast')

    def test_plotengine(self):
        """
        Test if Errors are raised if the provided plot engine is not supported.
        """
        with self.assertRaises(ValueError):
            tagplot(FIGS_AS_LIST, 1, PROJECT_ID, METHOD, location='north')
        with self.assertRaises(ValueError):
            tagplot(FIGS_AS_LIST, 'xyz', PROJECT_ID, METHOD, location='south')

    def test_idmethod(self):
        """
        Test if Errors are raised if the id_method is not an string.
        """
        with self.assertRaises(TypeError):
            tagplot(FIGS_AS_LIST, PLOT_ENGINE, PROJECT_ID, id_method=(0, 1),
                    location='west')
        with self.assertRaises(TypeError):
            tagplot(FIGS_AS_LIST, PLOT_ENGINE, PROJECT_ID, id_method=1)
        with self.assertRaises(TypeError):
            tagplot(FIGS_AS_LIST, PLOT_ENGINE, PROJECT_ID, id_method=[0, 1])

    def test_location(self):
        """
        Test if Errors are raised if the provided location is not supported.
        """
        with self.assertRaises(TypeError):
            tagplot(FIGS_AS_LIST, PLOT_ENGINE, PROJECT_ID, METHOD, location=1)
        with self.assertWarns(Warning):
            tagplot(FIGS_AS_LIST, PLOT_ENGINE, PROJECT_ID, METHOD,
                    location='up')


if __name__ == '__main__':
    unittest.main()
